IXP4xx: Change QMgr function names to qmgr_stat_*_watermark and clean the comments.

Signed-off-by: Krzysztof Hałasa <khc@pm.waw.pl>
diff --git a/drivers/net/arm/ixp4xx_eth.c b/drivers/net/arm/ixp4xx_eth.c
index 672c962..b6d1881 100644
--- a/drivers/net/arm/ixp4xx_eth.c
+++ b/drivers/net/arm/ixp4xx_eth.c
@@ -513,8 +513,8 @@
 #endif
 			napi_complete(napi);
 			qmgr_enable_irq(rxq);
-			if (!qmgr_stat_nearly_empty(rxq) &&
-			    napi_reschedule(napi)) { /* really empty in fact */
+			if (!qmgr_stat_below_low_watermark(rxq) &&
+			    napi_reschedule(napi)) { /* not empty again */
 #if DEBUG_RX
 				printk(KERN_DEBUG "%s: eth_poll"
 				       " napi_reschedule successed\n",
@@ -631,10 +631,9 @@
 			port->tx_buff_tab[n_desc] = NULL;
 		}
 
-		/* really empty in fact */
-		start = qmgr_stat_nearly_empty(port->plat->txreadyq);
+		start = qmgr_stat_below_low_watermark(port->plat->txreadyq);
 		queue_put_desc(port->plat->txreadyq, phys, desc);
-		if (start) {
+		if (start) { /* TX-ready queue was empty */
 #if DEBUG_TX
 			printk(KERN_DEBUG "%s: eth_txdone_irq xmit ready\n",
 			       port->netdev->name);
@@ -710,14 +709,14 @@
 	queue_put_desc(TX_QUEUE(port->id), tx_desc_phys(port, n), desc);
 	dev->trans_start = jiffies;
 
-	if (qmgr_stat_nearly_empty(txreadyq)) { /* really empty in fact */
+	if (qmgr_stat_below_low_watermark(txreadyq)) { /* empty */
 #if DEBUG_TX
 		printk(KERN_DEBUG "%s: eth_xmit queue full\n", dev->name);
 #endif
 		netif_stop_queue(dev);
 		/* we could miss TX ready interrupt */
 		/* really empty in fact */
-		if (!qmgr_stat_nearly_empty(txreadyq)) {
+		if (!qmgr_stat_below_low_watermark(txreadyq)) {
 #if DEBUG_TX
 			printk(KERN_DEBUG "%s: eth_xmit ready again\n",
 			       dev->name);
diff --git a/drivers/net/wan/ixp4xx_hss.c b/drivers/net/wan/ixp4xx_hss.c
index 1e56e58..a6dc317 100644
--- a/drivers/net/wan/ixp4xx_hss.c
+++ b/drivers/net/wan/ixp4xx_hss.c
@@ -790,11 +790,10 @@
 		free_buffer_irq(port->tx_buff_tab[n_desc]);
 		port->tx_buff_tab[n_desc] = NULL;
 
-		/* really empty in fact */
-		start = qmgr_stat_nearly_empty(port->plat->txreadyq);
+		start = qmgr_stat_below_low_watermark(port->plat->txreadyq);
 		queue_put_desc(port->plat->txreadyq,
 			       tx_desc_phys(port, n_desc), desc);
-		if (start) {
+		if (start) { /* TX-ready queue was empty */
 #if DEBUG_TX
 			printk(KERN_DEBUG "%s: hss_hdlc_txdone_irq xmit"
 			       " ready\n", dev->name);
@@ -869,13 +868,13 @@
 	queue_put_desc(queue_ids[port->id].tx, tx_desc_phys(port, n), desc);
 	dev->trans_start = jiffies;
 
-	if (qmgr_stat_nearly_empty(txreadyq)) { /* really empty in fact */
+	if (qmgr_stat_below_low_watermark(txreadyq)) { /* empty */
 #if DEBUG_TX
 		printk(KERN_DEBUG "%s: hss_hdlc_xmit queue full\n", dev->name);
 #endif
 		netif_stop_queue(dev);
 		/* we could miss TX ready interrupt */
-		if (!qmgr_stat_nearly_empty(txreadyq)) {
+		if (!qmgr_stat_below_low_watermark(txreadyq)) {
 #if DEBUG_TX
 			printk(KERN_DEBUG "%s: hss_hdlc_xmit ready again\n",
 			       dev->name);
diff --git a/arch/arm/mach-ixp4xx/include/mach/qmgr.h b/arch/arm/mach-ixp4xx/include/mach/qmgr.h
index 32077e1..9e7cad2 100644
--- a/arch/arm/mach-ixp4xx/include/mach/qmgr.h
+++ b/arch/arm/mach-ixp4xx/include/mach/qmgr.h
@@ -138,12 +138,12 @@
 }
 
 /**
  * qmgr_stat_empty() - checks if a hardware queue is nearly empty
  * @queue:	queue number
  *
  * Returns non-zero value if the queue is nearly or completely empty.
  */
-static inline int qmgr_stat_nearly_empty(unsigned int queue)
+static inline int qmgr_stat_below_low_watermark(unsigned int queue)
 {
 	extern struct qmgr_regs __iomem *qmgr_regs;
 	if (queue >= HALF_QUEUES)
@@ -153,19 +153,19 @@
 }
 
 /**
- * qmgr_stat_empty() - checks if a hardware queue is nearly full
+ * qmgr_stat_above_high_watermark() - checks if a queue is above high watermark
  * @queue:	queue number
  *
  * Returns non-zero value if the queue is nearly or completely full.
  */
-static inline int qmgr_stat_nearly_full(unsigned int queue)
+static inline int qmgr_stat_above_high_watermark(unsigned int queue)
 {
 	BUG_ON(queue >= HALF_QUEUES);
 	return __qmgr_get_stat1(queue) & QUEUE_STAT1_NEARLY_FULL;
 }
 
 /**
- * qmgr_stat_empty() - checks if a hardware queue is full
+ * qmgr_stat_full() - checks if a hardware queue is full
  * @queue:	queue number
  *
  * Returns non-zero value if the queue is full.
@@ -180,10 +180,10 @@
 }
 
 /**
- * qmgr_stat_empty() - checks if a hardware queue experienced underflow
+ * qmgr_stat_underflow() - checks if a hardware queue experienced underflow
  * @queue:	queue number
  *
- * Returns non-zero value if empty.
+ * Returns non-zero value if the queue experienced underflow.
  */
 static inline int qmgr_stat_underflow(unsigned int queue)
 {
@@ -191,10 +191,10 @@
 }
 
 /**
- * qmgr_stat_empty() - checks if a hardware queue experienced overflow
+ * qmgr_stat_overflow() - checks if a hardware queue experienced overflow
  * @queue:	queue number
  *
- * Returns non-zero value if empty.
+ * Returns non-zero value if the queue experienced overflow.
  */
 static inline int qmgr_stat_overflow(unsigned int queue)
 {
@@ -138,12 +138,12 @@
 
 /**
- * qmgr_stat_empty() - checks if a hardware queue is nearly empty
+ * qmgr_stat_below_low_watermark() - checks if a queue is below low watermark
  * @queue:	queue number
  *
@@ -138,12 +138,12 @@
  * @queue:	queue number
  *
- * Returns non-zero value if the queue is nearly or completely empty.
+ * Returns non-zero value if the queue is below low watermark.
  */
@@ -153,19 +153,19 @@
  * @queue:	queue number
  *
- * Returns non-zero value if the queue is nearly or completely full.
+ * Returns non-zero value if the queue is above high watermark
  */